@@ -8,19 +8,12 @@ import logging
 
 from .auth import Auth
 from .auth_by_plugin import AuthByPlugin
-from .compat import (urlsplit, unescape, urlencode)
-from .constants import (
-    HTTP_HEADER_CONTENT_TYPE,
-    HTTP_HEADER_ACCEPT,
-    HTTP_HEADER_USER_AGENT,
-    HTTP_HEADER_SERVICE_NAME,
-)
-from .errorcode import (ER_IDP_CONNECTION_ERROR,
-                        ER_INCORRECT_DESTINATION)
-from .errors import (Error, DatabaseError)
-from .network import (CONTENT_TYPE_APPLICATION_JSON,
-                      PYTHON_CONNECTOR_USER_AGENT)
-from .sqlstate import (SQLSTATE_CONNECTION_WAS_NOT_ESTABLISHED)
+from .compat import unescape, urlencode, urlsplit
+from .constants import HTTP_HEADER_ACCEPT, HTTP_HEADER_CONTENT_TYPE, HTTP_HEADER_SERVICE_NAME, HTTP_HEADER_USER_AGENT
+from .errorcode import ER_IDP_CONNECTION_ERROR, ER_INCORRECT_DESTINATION
+from .errors import DatabaseError, Error
+from .network import CONTENT_TYPE_APPLICATION_JSON, PYTHON_CONNECTOR_USER_AGENT
+from .sqlstate import SQLSTATE_CONNECTION_WAS_NOT_ESTABLISHED
 
 logger = logging.getLogger(__name__)
 
